idlehomescreen/inc/xnappuiadapter.h
branchRCL_3
changeset 30 b8fae6b8a148
parent 15 ff572dfe6d86
child 47 7be2816dbabd
--- a/idlehomescreen/inc/xnappuiadapter.h	Mon Mar 15 12:39:47 2010 +0200
+++ b/idlehomescreen/inc/xnappuiadapter.h	Wed Mar 31 21:17:19 2010 +0300
@@ -160,12 +160,12 @@
         CXnNodeAppIf& aDestination );
     
     /**
      * This is called when initial view is activated
      * To be overriden by subclass.
      * 
      * @since S60 5.2
      */
-    IMPORT_C virtual void UiActivated();
+    IMPORT_C virtual void HandleUiReadyEventL();
     
     /**     
      * Second-phase constructor
@@ -160,12 +160,12 @@
     
     /**
-     * This is called when initial view is activated
+     * This is called when (initial) view is ready
      * To be overriden by subclass.
      * 